@@ -1,7 +1,7 @@
 package App::wordlist;
 
 our $DATE = '2016-04-15'; # DATE
-our $VERSION = '0.22'; # VERSION
+our $VERSION = '0.23'; # VERSION
 
 use 5.010001;
 use strict;
@@ -145,10 +145,10 @@ _
             completion => sub {
                 my %args = @_;
                 my @langs;
-                for (@{ _list_installed() }) {
-                    next unless length $_->{lang};
-                    push @langs, $_->{lang}
-                        unless grep {$_ eq $_->{name}} @langs;
+                for my $rec (@{ _list_installed() }) {
+                    next unless length $rec->{lang};
+                    push @langs, $rec->{lang}
+                        unless grep {$_ eq $rec->{name}} @langs;
                 }
                 require Complete::Util;
                 Complete::Util::complete_array_elem(
@@ -372,7 +372,7 @@ App::wordlist - Grep words from WordList::*
 
 =head1 VERSION
 
-This document describes version 0.22 of App::wordlist (from Perl distribution App-wordlist), released on 2016-04-15.
+This document describes version 0.23 of App::wordlist (from Perl distribution App-wordlist), released on 2016-04-15.
 
 =head1 SYNOPSIS
 
